@@ -1,4 +1,4 @@
-from deep_utils.utils.utils.logging_ import log_print
+from deep_utils.utils.logging_utils import log_print
 
 
 class TensorboardTorch:
