@@ -19,3 +19,8 @@ from .re_utils import *
 from .random_utils import *
 from .memory_utils import *
 from .tensorboard_utils import *
+from .algorithm_utils import *
+from .multi_label_utils import *
+from .compress_utils import *
+from .lr_scheduler_utils import *
+from .logging_utils import *
