@@ -1,6 +1,6 @@
 import logging
 from typing import Union
-from deep_utils.utils.utils.logging_ import log_print, value_error_log
+from deep_utils.utils.logging_utils import log_print, value_error_log
 import numpy as np
 
 
