@@ -1,4 +1,4 @@
-def load_json(json_path: str, encoding="utf-8"):
+def load_json(json_path: str, encoding="utf-8") -> dict:
     """
     :param json_path: Path to json file to load
     :param encoding: encoding format
@@ -10,7 +10,7 @@ def load_json(json_path: str, encoding="utf-8"):
     return json_data
 
 
-def dump_json(json_path, dict_object: dict, encoding="utf-8", ensure_ascii=True):
+def dump_json(json_path, dict_object: dict, encoding="utf-8", ensure_ascii=True) -> None:
     """
     dumps a json file
     Args:
